import 'package:flutter/foundation.dart';
import 'package:flutter_flex_cart/src/item.dart';

const double MINIMUM_VALUE = 0.001;

abstract class CoreDetail<I extends CoreItem<ID>, ID> with ChangeNotifier {
  final I item;
  double _qty;
  double _discount;

  CoreDetail({
    required this.item,
    double qty = 1,
    double discount = 0,
  })  : _discount = discount,
        _qty = qty;

  double get qty => _qty;

  double get discount => _discount;

  set discount(double discount) {
    _discount = discount;
    notifyListeners();
  }

  double get price => item.price;

  double get unitPrice => item.price - _discount;

  double get lineTotal => unitPrice * qty;

  void increaseQty({double increment = 1}) {
    if (increment < 1) {
      if (_qty + increment > MINIMUM_VALUE) {
        _qty += increment;
      }
    } else {
      _qty += increment;
    }
    notifyListeners();
  }

  void resetQty() {
    _qty = 0.0;
    notifyListeners();
  }
}
