import 'package:flutter/foundation.dart';
import 'package:flutter_flex_cart/src/payment.dart';

/// Payable
/// Add payment support to cart or settlements or invoice.
/// * [P] CorePayment
mixin Payable<P extends CorePayment> on ChangeNotifier {
  late final List<P> _payments;

  Iterable<P> get payments => List.unmodifiable(_payments);

  int get noOfPayments => _payments.length;

  double get totalPayments =>
      _payments.fold(0.0, (previousValue, curr) => curr.amount);

  void setPayments(List<P> payments) {
    _payments = payments;
  }

  /// Add payment to list override this if you want any other logic when adding to the list
  /// Like if you want to add only one cash payment object summing up all the cash payments.
  void addPayment(P payment) {
    _payments.add(payment);
    notifyListeners();
  }

  void removePayment(int index) {
    _payments.removeAt(index);
    notifyListeners();
  }

  void reset() {
    _payments.clear();
    notifyListeners();
  }
}
