import 'package:flutter_flex_cart/flutter_flex_cart.dart';
import 'package:flutter_test/flutter_test.dart';

import 'mocks/item.dart';
import 'testing/cart.dart';
import 'testing/detail.dart';

void main() {
  group(Cart, () {
    late CoreCartBase cart;
    late ProductDetail productDetail1 = ProductDetail(
      item: item1,
      discount: 1.0,
      qty: 2,
    );

    setUp(() {
      cart = Cart();
    });

    test('should be zero when initialized', () {
      expect(0, cart.noOfItems);
      expect(0, cart.total);
    });

    test('should add detail', () {
      cart.addDetail(
        productDetail1,
      );
      expect(1, cart.noOfItems);
      expect(18, cart.total);
    });

    test('should remove detail', () {
      cart.addDetail(
        ProductDetail(
          item: item1,
          discount: 1.0,
        ),
      );
      cart.addDetail(
        ProductDetail(
          item: item1,
          discount: 2.0,
          qty: 2,
        ),
      );

      cart.removeDetail(0);

      expect(1, cart.noOfItems);
      expect(16, cart.total);
    });

    test('should reset clear the cart', () {
      cart.addDetail(productDetail1);

      cart.reset();

      expect(0, cart.noOfItems);
      expect(0, cart.total);
    });

    test('should return true if the item in the cart', () {
      cart.addDetail(productDetail1);

      expect(true, cart.isInTheCart(productDetail1.item.id));
    });
  });
}
